﻿Imports System.Data
Imports System.IO

Public Class frmMain

#Region "Variables"

    ''' <summary>
    ''' Wisys.AllSystem.ConnectionInfo is the Wisys Data Access Class
    ''' </summary>
    ''' <remarks>
    ''' The ConnectionInfo object should typically be instantiated one time in the application.  
    ''' The OpenWisysConnection and CloseWisysConnection methods are then used to Open and Close the SQL connections accordingly
    ''' </remarks>
    Private c_oWisysConnectionInfo As Wisys.AllSystem.ConnectionInfo
    Private c_dsApplicationExamples As DataSet

#End Region

#Region "Constructor"

    Public Sub New()

        ' This call is required by the designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.
        Me.Text = Application.ProductName
        lblAppTitle.Text = Application.ProductName
        DefaultSearch()
        c_oWisysConnectionInfo = New Wisys.AllSystem.ConnectionInfo()
        LoadDBSettings()
        BuildApplicationExampleList()
        DisplayApplicationExamples(cAppHelper.ApplicaitonCategory.Inventory)

    End Sub

#End Region

#Region "Private Methods"

    Private Sub DisplayApplicationExamples(applicationCategory As cAppHelper.ApplicaitonCategory)

        Me.SuspendLayout()
        flowAppPanel.Controls.Clear()
        Dim appRows As DataRow() = Nothing
        If (c_dsApplicationExamples IsNot Nothing AndAlso c_dsApplicationExamples.Tables("applicationlist") IsNot Nothing) Then
            appRows = c_dsApplicationExamples.Tables("applicationlist").Select("category = '" & cAppHelper.GetStringValue(applicationCategory) & "'")
            For Each appRow As DataRow In appRows
                AddApplicationExample(appRow)
            Next
        End If
        Me.ResumeLayout()

    End Sub

    Private Sub DisplayApplicationExamples(sSearchTerm As String)

        Me.SuspendLayout()
        flowAppPanel.Controls.Clear()
        Dim appRows As DataRow() = Nothing
        If (c_dsApplicationExamples IsNot Nothing AndAlso c_dsApplicationExamples.Tables("applicationlist") IsNot Nothing) Then
            appRows = c_dsApplicationExamples.Tables("tag").Select("tag_text like '%" & sSearchTerm & "%'")
            For Each appRow As DataRow In appRows
                Dim p_oParentRow As DataRow = Nothing
                p_oParentRow = appRow.GetParentRow("applicationlist_tag")
                AddApplicationExample(p_oParentRow)
            Next
        End If
        Me.ResumeLayout()

    End Sub

    Private Sub AddApplicationExample(oApplicationRow As DataRow)

        If (oApplicationRow Is Nothing) Then
            Return
        End If
        If (flowAppPanel.Controls.ContainsKey(oApplicationRow("usercontrol").ToString())) Then
            Return
        End If
        Dim p_ucAppDescription As New ucAppDescription
        p_ucAppDescription.ApplicationDescription = oApplicationRow("name").ToString()
        p_ucAppDescription.UserControlName = oApplicationRow("usercontrol").ToString()
        p_ucAppDescription.Name = oApplicationRow("usercontrol").ToString()
        AddHandler p_ucAppDescription.ucAppDescription_ButtonClick, AddressOf AppClick
        p_ucAppDescription.Margin = New Padding(10)
        flowAppPanel.Controls.Add(p_ucAppDescription)

    End Sub

    Private Sub BuildApplicationExampleList()

        Try
            c_dsApplicationExamples = New DataSet
            Dim p_sXMLApplicationExampleList As String = ""

            p_sXMLApplicationExampleList = System.IO.Path.GetFullPath(Application.StartupPath & "\app_data\ApplicationExampleList.xml")
            c_dsApplicationExamples.ReadXml(p_sXMLApplicationExampleList)

        Catch ex As Exception
            MessageBox.Show(ex.ToString())

        End Try

    End Sub

    Private Sub LoadDBSettings()

        Dim p_WisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        If (Not (String.IsNullOrEmpty(My.Settings.SQLServer) AndAlso String.IsNullOrEmpty(My.Settings.Database))) Then
            c_oWisysConnectionInfo.Parameters(My.Settings.SQLServer, My.Settings.Database)
        Else
            Dim p_oFrmSettings As New frmSettings(c_oWisysConnectionInfo)
            p_oFrmSettings.ShowDialog()
        End If

    End Sub

    Private Sub DefaultSearch()
        txtSearch.Text = "Search For A Table, Module, or Wisys Assembly (oeordhdr_sql, IM, wisys.im, etc...)"
        txtSearch.ForeColor = Color.Gray
    End Sub


#End Region

#Region "Events"

    Private Sub AppClick(ByVal sender As Object, ByVal e As System.EventArgs)

        If (String.IsNullOrWhiteSpace(c_oWisysConnectionInfo.Server) OrElse String.IsNullOrWhiteSpace(c_oWisysConnectionInfo.Database)) Then
            MessageBox.Show("Please set the Server and Database under the Settings option")
            Return
        End If

        Dim p_AppButton = DirectCast(sender, ucAppDescription)
        Using fMasterForm As New frmMasterForm(p_AppButton.ApplicationDescription, p_AppButton.UserControlName, c_oWisysConnectionInfo)
            fMasterForm.ShowDialog()
        End Using

    End Sub

    Private Sub lnkWisysBasics_LinkClicked(sender As System.Object, e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles lnkWisysBasics.LinkClicked
        DisplayApplicationExamples(cAppHelper.ApplicaitonCategory.WisysBasics)
    End Sub

    Private Sub linkAccountsReceivable_LinkClicked(sender As System.Object, e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles linkAccountsReceivable.LinkClicked
        DisplayApplicationExamples(cAppHelper.ApplicaitonCategory.AccountsReceivable)
    End Sub

    Private Sub linkBillOfMaterial_LinkClicked(sender As System.Object, e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles linkBillOfMaterial.LinkClicked
        DisplayApplicationExamples(cAppHelper.ApplicaitonCategory.BillOfMaterial)
    End Sub

    Private Sub linkInventory_LinkClicked(sender As System.Object, e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles linkInventory.LinkClicked
        DisplayApplicationExamples(cAppHelper.ApplicaitonCategory.Inventory)
    End Sub

    Private Sub linkOrderEntry_LinkClicked(sender As System.Object, e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles linkOrderEntry.LinkClicked
        DisplayApplicationExamples(cAppHelper.ApplicaitonCategory.OrderEntry)
    End Sub

    Private Sub linkPurchaseOrder_LinkClicked(sender As System.Object, e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles linkPurchaseOrder.LinkClicked
        DisplayApplicationExamples(cAppHelper.ApplicaitonCategory.PurchaseOrder)
    End Sub

    Private Sub linkShopFloor_LinkClicked(sender As System.Object, e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles linkShopFloor.LinkClicked
        DisplayApplicationExamples(cAppHelper.ApplicaitonCategory.ShopFloor)
    End Sub

    Private Sub linkProductionOrder_LinkClicked(sender As System.Object, e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles linkProductionOrder.LinkClicked
        DisplayApplicationExamples(cAppHelper.ApplicaitonCategory.ProductionOrder)
    End Sub

    Private Sub linkSettings_LinkClicked(sender As System.Object, e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles linkSettings.LinkClicked

        Using fLogin As New frmSettings(c_oWisysConnectionInfo)
            fLogin.ShowDialog()
        End Using

    End Sub

    Private Sub linkExit_LinkClicked(sender As System.Object, e As System.Windows.Forms.LinkLabelLinkClickedEventArgs) Handles linkExit.LinkClicked

        Me.Close()

    End Sub

    Private Sub txtSearch_Leave(sender As System.Object, e As System.EventArgs) Handles txtSearch.Leave
        If (txtSearch.Text.Trim = "") Then
            DefaultSearch()
        End If

    End Sub

    Private Sub txtSearch_Enter(sender As System.Object, e As System.EventArgs) Handles txtSearch.Enter
        txtSearch.Text = ""
    End Sub

    Private Sub btnSearch_Click(sender As System.Object, e As System.EventArgs) Handles btnSearch.Click

        DisplayApplicationExamples(txtSearch.Text)

    End Sub

    Private Sub txtSearch_KeyPress(sender As System.Object, e As System.Windows.Forms.KeyPressEventArgs) Handles txtSearch.KeyPress

        If (e.KeyChar = ChrW(Keys.Return)) Then
            btnSearch.PerformClick()
        End If

    End Sub

#End Region

End Class