﻿Imports System.Configuration
Imports Wisys.AllSystem
Imports Wisys.OeTrx
Imports System.Collections.Generic


Public Class ucOEOrderTransactions

#Region "Variables"

    Private c_oWisysConnection As Wisys.AllSystem.ConnectionInfo
    Private c_oWisysTrxCommon As Wisys.AllSystem.TrxCommon
    Private c_oOrderEntryTables As Wisys.Oe.OrderEntryTables
    Private c_oInventoryTables As Wisys.Im.InventoryTables

#End Region

#Region "Constructor"

    Public Sub New(oConnectionInfo As Wisys.AllSystem.ConnectionInfo)

        ' This call is required by the designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.
        LoadOrderTypes()
        c_oWisysConnection = oConnectionInfo

        '//Instantiate the OrderEntryTables object 
        '//    Assign our Wisys ConnectionInfo object using the object's Connection method
        Dim p_sWisysReturnMessage As String = ""
        c_oOrderEntryTables = New Wisys.Oe.OrderEntryTables()
        c_oOrderEntryTables.Connection(c_oWisysConnection, p_sWisysReturnMessage)

        c_oInventoryTables = New Wisys.Im.InventoryTables()
        c_oInventoryTables.Connection(c_oWisysConnection)

        c_oWisysTrxCommon = New Wisys.AllSystem.TrxCommon()
        c_oWisysTrxCommon.Connection(c_oWisysConnection)

    End Sub

#End Region

#Region "Private Methods"

    Private Sub LoadOrderTypes()

        Dim p_oDictionary As New Dictionary(Of String, String)()
        p_oDictionary.Add(cAppHelper.GetStringValue(cAppHelper.OrderType.Order), cAppHelper.OrderType.Order.ToString)
        p_oDictionary.Add(cAppHelper.GetStringValue(cAppHelper.OrderType.CreditMemo), cAppHelper.OrderType.CreditMemo.ToString)
        cbOrderType.DataSource = New BindingSource(p_oDictionary, Nothing)
        cbOrderType.DisplayMember = "Value"
        cbOrderType.ValueMember = "Key"

    End Sub

    Private Sub ClearScreen()

    End Sub

    Private Function PickOrder(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_bRecordFound As Boolean = False
        Dim p_eOrderType As Wisys.AllSystem.TrxEnums.OeOrderTypeEnum

        Try
            '//Pass the Connection
            c_oOrderEntryTables.Connection(c_oWisysConnection, sWisysReturnMessage)

            '//Get Order Type Enumeration
            p_eOrderType = c_oWisysTrxCommon.ReturnOEOrderTypeEnum(cbOrderType.SelectedValue)

            '//Read Order and Line Items
            p_iWisysReturnValue = c_oOrderEntryTables.OrderHeader.Read(p_eOrderType _
                                                                     , txtOrderNo.Text _
                                                                     , True _
                                                                     , True _
                                                                     , False _
                                                                     , p_bRecordFound _
                                                                     , sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If
            If (p_bRecordFound = False) Then
                sWisysReturnMessage = Wisys.AllSystem.Constants.ORDER_NO_FOUND
                Return FAILED
            End If

            '//Mark each line as Picked
            For Each p_oOeordlin As Wisys.Oe.OEORDLIN In c_oOrderEntryTables.OrderHeader.OrderLines
                p_oOeordlin.User = txtUser.Text
                p_iWisysReturnValue = c_oOrderEntryTables.OrderHeader.SetHeaderLinePickedPrinted(p_oOeordlin.Line_no _
                                                                                               , DateTime.Now _
                                                                                               , sWisysReturnMessage)
                If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                    Return p_iWisysReturnValue
                End If
            Next

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Function ConfirmShipOrder(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_bRecordFound As Boolean = False
        Dim p_eOrderType As Wisys.AllSystem.TrxEnums.OeOrderTypeEnum

        Dim p_oConfirmShip As New Wisys.OeTrx.ConfirmShip


        Try

            '//Pass the Connection
            c_oOrderEntryTables.Connection(c_oWisysConnection, sWisysReturnMessage)
            p_oConfirmShip.Connection(c_oWisysConnection)

            '//Get Order Type Enumeration
            p_eOrderType = c_oWisysTrxCommon.ReturnOEOrderTypeEnum(cbOrderType.SelectedValue)

            '//Read Order and Line Items
            p_iWisysReturnValue = c_oOrderEntryTables.OrderHeader.Read(p_eOrderType _
                                                                     , txtOrderNo.Text _
                                                                     , True _
                                                                     , True _
                                                                     , False _
                                                                     , p_bRecordFound _
                                                                     , sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If
            If (p_bRecordFound = False) Then
                sWisysReturnMessage = Wisys.AllSystem.Constants.ORDER_NO_FOUND
                Return FAILED
            End If

            '//Confirm Ship each line 
            For Each p_oOeordlin As Wisys.Oe.OEORDLIN In c_oOrderEntryTables.OrderHeader.OrderLines

                '//Assign Confirm Ship Properties
                p_oConfirmShip.OrderNumber = c_oOrderEntryTables.OrderHeader.Ord_no
                p_oConfirmShip.LineNumber = p_oOeordlin.Line_no
                p_oConfirmShip.ItemNumber = p_oOeordlin.Item_no
                p_oConfirmShip.Location = p_oOeordlin.Loc
                p_oConfirmShip.Quantity = p_oOeordlin.Qty_to_ship

                '//The ConfirmShip.IsBulkTransaction property can be utilized when shipping multiple line items in a single transaction.
                '//This Property improves performance by updating the Order Header accumulators after all line items have been shipped
                '//The ***Wisys.OETrx.ConfirmShip.FinalizeBulkTransaction*** Method must be called after all Line Items have been shipped 
                p_oConfirmShip.IsBulkTransaction = True

                '//Username for Audits
                p_oConfirmShip.UserName = txtUser.Text

                '//Confirm Ship kit components automatically if parent/components are not binnned/serialized/lotted
                '//See Confirm Ship Kit Exmaple for more information 
                p_oConfirmShip.ConfirmShipKitComponents = True


                '//Check For Bin/Serial/Lot
                '//Determine If Item Is Inventory or Non Inventory
                p_bRecordFound = False
                c_oInventoryTables.Connection(c_oWisysConnection)
                p_iWisysReturnValue = c_oInventoryTables.Imitmidx.Read(p_oOeordlin.Item_no _
                                                                     , p_oOeordlin.Loc _
                                                                     , True _
                                                                     , p_bRecordFound _
                                                                     , sWisysReturnMessage)
                If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                    Return p_iWisysReturnValue
                End If

                '//Add Bin, Lot, Serial information for Confirm Ship
                If (p_bRecordFound AndAlso _
                    (c_oInventoryTables.Imitmidx.Ser_lot_fg = "L" OrElse _
                     c_oInventoryTables.Imitmidx.Ser_lot_fg = "S" OrElse _
                     c_oInventoryTables.Imitmidx.Iminvloc.Binned)) Then

                    Dim p_oWisysBinCollection As New Wisys.AllSystem.DataStructures.ItemBins
                    Dim p_oWisysSerialLotCollection As New Wisys.AllSystem.DataStructures.ItemSerialLots

                    Dim p_frmBinSerialLotDialog As New frmBinSerialLotDialog()
                    p_frmBinSerialLotDialog.lblTitle.Text = "Item No: " & p_oOeordlin.Item_no.Trim() & " | Qty To Ship: " & p_oOeordlin.Qty_to_ship.ToString()
                    p_frmBinSerialLotDialog.ShowDialog()
                    p_frmBinSerialLotDialog.UcBinSerialLotGrid1.GetBinSerialLotCollection(p_oWisysBinCollection, p_oWisysSerialLotCollection)
                    If (p_oWisysBinCollection IsNot Nothing AndAlso p_oWisysBinCollection.Count > 0) Then
                        p_oConfirmShip.IssueBins = p_oWisysBinCollection
                    End If
                    If (p_oWisysSerialLotCollection IsNot Nothing AndAlso p_oWisysSerialLotCollection.Count > 0) Then
                        p_oConfirmShip.SerialLots = p_oWisysSerialLotCollection
                    End If

                End If

                p_iWisysReturnValue = p_oConfirmShip.PostTrx(sWisysReturnMessage)
                If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                    Return p_iWisysReturnValue
                End If

            Next

            '//FinalizeBulkTransaction should be used in conjuction with the IsBulkTransaction property            
            p_oConfirmShip.UserName = txtUser.Text
            p_iWisysReturnValue = p_oConfirmShip.FinalizeBulkTransaction(c_oOrderEntryTables.OrderHeader.Ord_no, sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Function ConfirmBillOrder(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_bRecordFound As Boolean = False
        Dim p_eOrderType As Wisys.AllSystem.TrxEnums.OeOrderTypeEnum

        Dim p_oConfirmBill As New Wisys.OeTrx.ConfirmBill

        Try

            '//Pass the Connection
            c_oOrderEntryTables.Connection(c_oWisysConnection, sWisysReturnMessage)
            p_oConfirmBill.Connection(c_oWisysConnection)

            '//Get Order Type Enumeration
            p_eOrderType = c_oWisysTrxCommon.ReturnOEOrderTypeEnum(cbOrderType.SelectedValue)

            '//Read Order and Line Items
            p_iWisysReturnValue = c_oOrderEntryTables.OrderHeader.Read(p_eOrderType _
                                                                     , txtOrderNo.Text _
                                                                     , True _
                                                                     , True _
                                                                     , False _
                                                                     , p_bRecordFound _
                                                                     , sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If
            If (p_bRecordFound = False) Then
                sWisysReturnMessage = Wisys.AllSystem.Constants.ORDER_NO_FOUND
                Return FAILED
            End If

            '//Confirm Bill each line 
            For Each p_oOeordlin As Wisys.Oe.OEORDLIN In c_oOrderEntryTables.OrderHeader.OrderLines

                '//Assign Confirm Ship Properties
                p_oConfirmBill.OrderNumber = c_oOrderEntryTables.OrderHeader.Ord_no
                p_oConfirmBill.LineNumber = p_oOeordlin.Line_no
                p_oConfirmBill.ItemNumber = p_oOeordlin.Item_no
                p_oConfirmBill.Location = p_oOeordlin.Loc
                p_oConfirmBill.Quantity = p_oOeordlin.Qty_to_ship

                '//Username for Audits
                p_oConfirmBill.UserName = txtUser.Text

                '//See Confirm Bill Kit Exmaple for more information 
                p_oConfirmBill.IsKitOrFeatureComponent = False

                '//Check For Bin/Serial/Lot
                '//Determine If Item Is Inventory or Non Inventory
                p_bRecordFound = False
                c_oInventoryTables.Connection(c_oWisysConnection)
                p_iWisysReturnValue = c_oInventoryTables.Imitmidx.Read(p_oOeordlin.Item_no _
                                                                     , p_oOeordlin.Loc _
                                                                     , True _
                                                                     , p_bRecordFound _
                                                                     , sWisysReturnMessage)
                If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                    Return p_iWisysReturnValue
                End If

                '//Add Bin, Lot, Serial information for Confirm Bill
                If (p_bRecordFound AndAlso _
                    (c_oInventoryTables.Imitmidx.Ser_lot_fg = "L" OrElse _
                     c_oInventoryTables.Imitmidx.Ser_lot_fg = "S" OrElse _
                     c_oInventoryTables.Imitmidx.Iminvloc.Binned)) Then

                    Dim p_oWisysBinCollection As New Wisys.AllSystem.DataStructures.ItemBins
                    Dim p_oWisysSerialLotCollection As New Wisys.AllSystem.DataStructures.ItemSerialLots

                    Dim p_frmBinSerialLotDialog As New frmBinSerialLotDialog()
                    p_frmBinSerialLotDialog.lblTitle.Text = "Item No: " & p_oOeordlin.Item_no.Trim() & " | Qty to Ship: " & p_oOeordlin.Qty_to_ship.ToString()
                    p_frmBinSerialLotDialog.ShowDialog()
                    p_frmBinSerialLotDialog.UcBinSerialLotGrid1.GetBinSerialLotCollection(p_oWisysBinCollection, p_oWisysSerialLotCollection)
                    If (p_oWisysBinCollection IsNot Nothing AndAlso p_oWisysBinCollection.Count > 0) Then
                        p_oConfirmBill.IssueBins = p_oWisysBinCollection
                    End If
                    If (p_oWisysSerialLotCollection IsNot Nothing AndAlso p_oWisysSerialLotCollection.Count > 0) Then
                        p_oConfirmBill.SerialLots = p_oWisysSerialLotCollection
                    End If

                End If

                p_iWisysReturnValue = p_oConfirmBill.PostTrx(sWisysReturnMessage)
                If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                    Return p_iWisysReturnValue
                End If

            Next

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Function UnConfirmShipOrder(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_bRecordFound As Boolean = False
        Dim p_eOrderType As Wisys.AllSystem.TrxEnums.OeOrderTypeEnum

        Dim p_oUnConfirmShip As New Wisys.OeTrx.UnconfirmShip


        Try

            '//Pass the Connection
            c_oOrderEntryTables.Connection(c_oWisysConnection, sWisysReturnMessage)
            p_oUnConfirmShip.Connection(c_oWisysConnection)

            '//Get Order Type Enumeration
            p_eOrderType = c_oWisysTrxCommon.ReturnOEOrderTypeEnum(cbOrderType.SelectedValue)

            '//Read Order and Line Items
            p_iWisysReturnValue = c_oOrderEntryTables.OrderHeader.Read(p_eOrderType _
                                                                     , txtOrderNo.Text _
                                                                     , True _
                                                                     , True _
                                                                     , False _
                                                                     , p_bRecordFound _
                                                                     , sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If
            If (p_bRecordFound = False) Then
                sWisysReturnMessage = Wisys.AllSystem.Constants.ORDER_NO_FOUND
                Return FAILED
            End If

            '//Confirm Ship each line 
            For Each p_oOeordlin As Wisys.Oe.OEORDLIN In c_oOrderEntryTables.OrderHeader.OrderLines

                '//Assign Confirm Ship Properties
                p_oUnConfirmShip.OrderNumber = c_oOrderEntryTables.OrderHeader.Ord_no
                p_oUnConfirmShip.LineNumber = p_oOeordlin.Line_no
                p_oUnConfirmShip.ItemNumber = p_oOeordlin.Item_no
                p_oUnConfirmShip.Location = p_oOeordlin.Loc

                '//Username for Audits
                p_oUnConfirmShip.UserName = txtUser.Text

                '//See Confirm Ship Kit Exmaple for more information 
                p_oUnConfirmShip.IsKitOrFeatureComponent = False

                p_iWisysReturnValue = p_oUnConfirmShip.PostTrx(sWisysReturnMessage)
                If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                    Return p_iWisysReturnValue
                End If

            Next

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Function BillOrder(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_bRecordFound As Boolean = False
        Dim p_eOrderType As Wisys.AllSystem.TrxEnums.OeOrderTypeEnum

        Dim p_oPostBillingUpdates As New Wisys.OeTrx.PostBillingUpdates


        Try

            '//Pass the Connection
            c_oOrderEntryTables.Connection(c_oWisysConnection, sWisysReturnMessage)
            p_oPostBillingUpdates.Connection(c_oWisysConnection)

            '//Get Order Type Enumeration
            p_eOrderType = c_oWisysTrxCommon.ReturnOEOrderTypeEnum(cbOrderType.SelectedValue)

            '//Read Order and Line Items
            p_iWisysReturnValue = c_oOrderEntryTables.OrderHeader.Read(p_eOrderType _
                                                                     , txtOrderNo.Text _
                                                                     , True _
                                                                     , True _
                                                                     , False _
                                                                     , p_bRecordFound _
                                                                     , sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If
            If (p_bRecordFound = False) Then
                sWisysReturnMessage = Wisys.AllSystem.Constants.ORDER_NO_FOUND
                Return FAILED
            End If

            '//Assign Billing Properties
            p_oPostBillingUpdates.OrderType = c_oOrderEntryTables.OrderHeader.Ord_type
            p_oPostBillingUpdates.OrderNo = c_oOrderEntryTables.OrderHeader.Ord_no

            If (String.IsNullOrWhiteSpace(txtMiscAmount.Text) = False) Then
                p_oPostBillingUpdates.MiscAmount = CDbl(txtMiscAmount.Text)
            End If

            '//Override Misc Account
            If (String.IsNullOrWhiteSpace(txtMiscAccountMNNo.Text) = False) Then
                p_oPostBillingUpdates.Misc_mn_no = txtMiscAccountMNNo.Text
                p_oPostBillingUpdates.Misc_sb_no = txtMiscAccountSBNo.Text
                p_oPostBillingUpdates.Misc_db_no = txtMiscAccountDPNo.Text
            End If


            If (String.IsNullOrWhiteSpace(txtFreightAmount.Text) = False) Then
                p_oPostBillingUpdates.FreightAmount = CDbl(txtFreightAmount.Text)
            End If

            '//Override Freight Account
            If (String.IsNullOrWhiteSpace(txtFreightAccountMNNo.Text) = False) Then
                p_oPostBillingUpdates.Freight_Mn_no = txtFreightAccountMNNo.Text
                p_oPostBillingUpdates.Freight_sb_no = txtFreightAccountSBNo.Text
                p_oPostBillingUpdates.Freight_db_no = txtFreightAccountDPNo.Text
            End If

            '//Username for Audits
            p_oPostBillingUpdates.UserName = txtUser.Text

            p_iWisysReturnValue = p_oPostBillingUpdates.Post(TrxEnums.SelectBillingMode.FinalPost, sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Function InvoiceOrder(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = 0

        Try
            '//Pass the Connection
            c_oOrderEntryTables.Connection(c_oWisysConnection, sWisysReturnMessage)

            '//Username for Audits
            c_oOrderEntryTables.Username = txtUser.Text

            '//Invoice Order and Lines 
            p_iWisysReturnValue = c_oOrderEntryTables.AdvanceToInvoice(cbOrderType.SelectedValue, txtOrderNo.Text, DateTime.Now, sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Function VoidInvoice(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = 0

        Try
            '//Pass the Connection
            c_oOrderEntryTables.Connection(c_oWisysConnection, sWisysReturnMessage)

            '//Username for Audits
            c_oOrderEntryTables.Username = txtUser.Text

            '//Void Invoice Order and Lines 
            p_iWisysReturnValue = c_oOrderEntryTables.VoidInvoice(cbOrderType.SelectedValue, txtOrderNo.Text, sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Function LoadOrder(sOrderType As String, sOrderNo As String, ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = 0

        Try

            '//Pass the Connection
            c_oOrderEntryTables.Connection(c_oWisysConnection, sWisysReturnMessage)

            '//Read The Order And Line Items
            Dim p_eOrderType As Wisys.AllSystem.TrxEnums.OeOrderTypeEnum
            Dim p_bRecordFound As Boolean = False
            p_eOrderType = c_oWisysTrxCommon.ReturnOEOrderTypeEnum(sOrderType)
            p_iWisysReturnValue = c_oOrderEntryTables.OrderHeader.Read(p_eOrderType _
                                                                     , sOrderNo _
                                                                     , False _
                                                                     , False _
                                                                     , True _
                                                                     , p_bRecordFound _
                                                                     , sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If
            If (p_bRecordFound = False) Then
                sWisysReturnMessage = Wisys.AllSystem.Constants.ORDER_NO_FOUND
                Return FAILED
            End If

            DisplayOrder()

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function


    Private Sub DisplayOrder()

        txtOrderNo.Text = c_oOrderEntryTables.OrderHeader.Ord_no
        txtOrderStatus.Text = c_oOrderEntryTables.OrderHeader.Status

    End Sub

#End Region

#Region "Events"

    Private Sub btnLoadOrder_Click(sender As System.Object, e As System.EventArgs)

    End Sub

    Private Sub btnPickOrder_Click(sender As System.Object, e As System.EventArgs) Handles btnPickOrder.Click

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try
            '//Start Wisys SQL Transaction
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//Mark Order Lines as Picked
            p_iWisysReturnValue = PickOrder(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Pick Order")
            End If

            '//Close Wisys Connection
            Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
            p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

            p_iWisysReturnValue = LoadOrder(cbOrderType.SelectedValue, txtOrderNo.Text, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Load Order")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Pick Order")

        End Try

    End Sub

    Private Sub bntConfirmShip_Click(sender As System.Object, e As System.EventArgs) Handles bntConfirmShip.Click

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try
            '//Start Wisys SQL Transaction
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//Confirm Ship Order Lines 
            p_iWisysReturnValue = ConfirmShipOrder(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Confirm Ship Order")
            End If

            '//Close Wisys Connection
            Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
            p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

            p_iWisysReturnValue = LoadOrder(cbOrderType.SelectedValue, txtOrderNo.Text, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Load Order")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Confirm Ship Order")

        End Try

    End Sub

    Private Sub btnConfirmBill_Click(sender As System.Object, e As System.EventArgs) Handles btnConfirmBill.Click

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try
            '//Start Wisys SQL Transaction
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//Confirm Bill Order Lines 
            p_iWisysReturnValue = ConfirmBillOrder(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Confirm Bill Order")
            End If

            '//Close Wisys Connection
            Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
            p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

            p_iWisysReturnValue = LoadOrder(cbOrderType.SelectedValue, txtOrderNo.Text, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Load Order")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Confirm Bill Order")

        End Try

    End Sub

    Private Sub btnUnconfirmShip_Click(sender As System.Object, e As System.EventArgs) Handles btnUnconfirmShip.Click


        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try
            '//Start Wisys SQL Transaction
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//UnConfirm Ship Order Lines 
            p_iWisysReturnValue = UnConfirmShipOrder(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "UnConfirm Ship Order")
            End If

            '//Close Wisys Connection
            Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
            p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

            p_iWisysReturnValue = LoadOrder(cbOrderType.SelectedValue, txtOrderNo.Text, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Load Order")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "UnConfirm Ship Order")

        End Try

    End Sub

    Private Sub btnBillOrder_Click(sender As System.Object, e As System.EventArgs) Handles btnBillOrder.Click

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try
            '//Start Wisys SQL Transaction
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//Bill Order 
            p_iWisysReturnValue = BillOrder(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Bill Order")
            End If

            '//Close Wisys Connection
            Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
            p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

            p_iWisysReturnValue = LoadOrder(cbOrderType.SelectedValue, txtOrderNo.Text, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Load Order")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Bill Order")

        End Try


    End Sub

    Private Sub btnInvoice_Click(sender As System.Object, e As System.EventArgs) Handles btnInvoice.Click

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try
            '//Start Wisys SQL Transaction
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//Invoice Order
            p_iWisysReturnValue = InvoiceOrder(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Invoice Order")
            End If

            '//Close Wisys Connection
            Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
            p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

            p_iWisysReturnValue = LoadOrder(cbOrderType.SelectedValue, txtOrderNo.Text, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Load Order")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Invoice Order")

        End Try

    End Sub

    Private Sub btnVoidInvoice_Click(sender As System.Object, e As System.EventArgs) Handles btnVoidInvoice.Click

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try
            '//Start Wisys SQL Transaction
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//Void Invoice 
            p_iWisysReturnValue = VoidInvoice(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Void Invoice")
            End If

            '//Close Wisys Connection
            Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
            p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

            p_iWisysReturnValue = LoadOrder(cbOrderType.SelectedValue, txtOrderNo.Text, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Load Order")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Void Invoice")

        End Try

    End Sub

#End Region





   
End Class
