﻿Imports System.Data.SqlClient
Imports Wisys.AllSystem
Imports Wisys.ImTrx

Public Class ucWBCompositeTransaction

#Region "Variables"

    Private c_oWisysConnection As Wisys.AllSystem.ConnectionInfo

#End Region

#Region "Constructor"

    Public Sub New(ByRef oConnectionInfo As Wisys.AllSystem.ConnectionInfo)

        ' This call is required by the designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.
        c_oWisysConnection = oConnectionInfo


    End Sub

#End Region

#Region "Properties"

#End Region

#Region "Private Methods"

    Private Function TransferTransaction(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = ReturnCodes.SUCCESSFUL
        Dim p_oTransfer As New Wisys.ImTrx.Transfer

        Try
            '//Set Transfer Object's Conneciton
            p_oTransfer.Connection(c_oWisysConnection)

            '//Set Properties for IM Transaction
            p_oTransfer.ItemNumber = txtItemNo.Text
            p_oTransfer.FromLocation = txtLocation.Text
            p_oTransfer.ToLocation = txtToLocation.Text
            p_oTransfer.Quantity = CDbl(txtQuantity.Text)
            p_oTransfer.UserName = txtUserName.Text

            p_oTransfer.BinNoFromFlatEntryValue = txtFromBinNo.Text
            p_oTransfer.BinNoToFlatEntryValue = txtToBinNo.Text
            p_oTransfer.SerialLotFlatEntryValue = txtSerialLotNo.Text

            '//Post Transfer 
            p_iWisysReturnValue = p_oTransfer.PostTrx(sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If

            txtTransferTransactionID.Text = p_oTransfer.InvtrxRecordID

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = Wisys.AllSystem.ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Function IssueTransaction(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = ReturnCodes.SUCCESSFUL
        Dim p_oIssue As New Wisys.ImTrx.Issue

        Try
            '//Set Transfer Object's Conneciton
            p_oIssue.Connection(c_oWisysConnection)

            '//Set Properties for IM Issue
            p_oIssue.ItemNumber = txtItemNo.Text
            p_oIssue.Location = txtToLocation.Text
            p_oIssue.Quantity = CDbl(txtQuantity.Text)
            p_oIssue.UserName = txtUserName.Text

            p_oIssue.BinNoFlatEntryValue = txtToBinNo.Text
            p_oIssue.SerialLotFlatEntryValue = txtSerialLotNo.Text

            '//Post Issue 
            p_iWisysReturnValue = p_oIssue.PostTrx(sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If

            txtIssueTransactionID.Text = p_oIssue.InvtrxRecordID

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = Wisys.AllSystem.ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Function CustomSQLTransaction(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = ReturnCodes.SUCCESSFUL

        Try
            Using p_oSQLCommand As New SqlCommand()
                p_oSQLCommand.CommandText = "Update IMITMIDX_SQL set user_def_fld_5 = @user_def_fld_5 where item_no = @item_no"
                p_oSQLCommand.Parameters.AddWithValue("@user_def_fld_5", txtUserDefinedField5.Text)
                p_oSQLCommand.Parameters.AddWithValue("@item_no", txtItemNo.Text.Trim)
                p_iWisysReturnValue = c_oWisysConnection.SqlProcessor.ProcessSQL(p_oSQLCommand, True, sWisysReturnMessage)
                If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                    Return p_iWisysReturnValue
                End If
            End Using

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

#End Region

    Private Sub btnComposite_Click(sender As System.Object, e As System.EventArgs) Handles btnComposite.Click
        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try

            '//Start Wisys SQL Transaction
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//Transfer Transaction
            p_iWisysReturnValue = TransferTransaction(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Transfer Transaction")
            End If

            '//Issue Transaction
            p_iWisysReturnValue = IssueTransaction(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Issue Transaction")
            End If

            '//Custom SQL Update
            p_iWisysReturnValue = CustomSQLTransaction(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Custom SQL Update")
            End If

            '//Close Wisys Connection (commit/rollback)
            Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
            p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Composite Transaction")
        End Try
    End Sub

    Private Sub Panel1_Paint(sender As System.Object, e As System.Windows.Forms.PaintEventArgs) Handles Panel1.Paint

    End Sub
End Class
