﻿Imports System.Data.SqlClient
Imports Wisys.AllSystem
Imports Wisys.ImTrx

Public Class ucWBLockHandling

#Region "Variables"

    Private c_oWisysConnection As Wisys.AllSystem.ConnectionInfo

#End Region

#Region "Properties"

#End Region

#Region "Constructor"

    Public Sub New(oWisysConnection As Wisys.AllSystem.ConnectionInfo)

        ' This call is required by the designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.
        c_oWisysConnection = oWisysConnection

    End Sub

#End Region

#Region "Public Methods"

#End Region

#Region "Private Methods"

    Private Function TransferTransaction(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = ReturnCodes.SUCCESSFUL
        Dim p_oTransfer As New Wisys.ImTrx.Transfer

        Try
            '//Set Transfer Object's Conneciton
            p_oTransfer.Connection(c_oWisysConnection)

            '//Set Properties for IM Transaction
            p_oTransfer.DocumentDate = dtDocumentDate.Value
            p_oTransfer.ItemNumber = txtItemNo.Text
            p_oTransfer.FromLocation = txtLocation.Text
            p_oTransfer.ToLocation = txtToLocation.Text
            p_oTransfer.Quantity = CDbl(txtQuantity.Text)
            p_oTransfer.UserName = txtUserName.Text

            p_oTransfer.BinNoFromFlatEntryValue = txtFromBinNo.Text
            p_oTransfer.BinNoToFlatEntryValue = txtToBinNo.Text
            p_oTransfer.SerialLotFlatEntryValue = ""

            '//Post Transfer 
            p_iWisysReturnValue = p_oTransfer.PostTrx(sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If

            txtTransactionID.Text = p_oTransfer.InvtrxRecordID

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = Wisys.AllSystem.ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

#End Region

#Region "Events"

    Private Sub btnTransfer_Click(sender As System.Object, e As System.EventArgs) Handles btnTransfer.Click

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try

            '//Transfer Transaction With Lock Handling
            Dim p_iTransactionAttempt As Int16 = 0
            Dim p_bEndTransaction As Boolean = False
            Dim p_bRecordLocked As Boolean = False

            '//MacLock handling option 
            '//Create a loop that retries the transaction X times over X seconds if a locking error is encountered
            '//The Wisys Connection should be Opened and Closed during each retry
            Do Until p_iTransactionAttempt >= 10 Or p_bEndTransaction = True

                p_iTransactionAttempt += 1
                Debug.WriteLine("Transfer Attempt: " & p_iTransactionAttempt.ToString())

                If (p_bRecordLocked = True) Then
                    p_bRecordLocked = False
                    System.Threading.Thread.Sleep(3000)
                End If

                '//Start Wisys SQL Transaction
                p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
                If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                    MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                    Exit Do
                End If

                '//Transfer Transaction
                p_iWisysReturnValue = TransferTransaction(p_sWisysReturnMessage)
                If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then

                    '//If a MacLock record is encountered a value of -2 will be returned
                    If (p_iWisysReturnValue = ReturnCodes.RECORD_LOCKED_BY_ANOTHER_USER) Then
                        p_bRecordLocked = True
                    Else
                        '//Transfer Failed from a non-locking error
                        p_bEndTransaction = True
                        MessageBox.Show(p_sWisysReturnMessage, "Transfer Transaction")
                    End If
                Else
                    '//Transfer Successful
                    p_bEndTransaction = True
                End If


                '//Close Wisys Connection (commit/rollback)
                '//If a Record Lock error is encountered a Rollback should be performed before retrying the transaction
                Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
                p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
                p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
                If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                    MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
                    Exit Do
                End If

            Loop

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Transfer Transaction")

        End Try

    End Sub

#End Region

End Class
