﻿Imports System.Data.SqlClient
Imports Wisys.AllSystem

Public Class ucWBSQLProcessor

#Region "Variables"

    Private c_oWisysConnection As Wisys.AllSystem.ConnectionInfo
    Private Const c_CUSTOMSQLDEFAULT As String = "Enter a SQL Select, Insert, Update, Or Delete Command"
    Private c_oBindingSource As New BindingSource

#End Region

#Region "Properties"

#End Region

#Region "Constructor"

    Public Sub New(ByRef oConnectionInfo As Wisys.AllSystem.ConnectionInfo)

        ' This call is required by the designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.
        DefaultCustomSQL()
        c_oWisysConnection = oConnectionInfo

        gridSQLOutput.DataSource = c_oBindingSource

    End Sub

#End Region

#Region "Public Methods"

#End Region

#Region "Private Methods"

    Private Sub DefaultCustomSQL()

        txtCustomSQL.Text = "Enter a SQL Select, Insert, Update, Or Delete Command"
        txtCustomSQL.ForeColor = Color.Gray

    End Sub

    Private Function ExecuteSQL(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_oDataRow As DataRow = Nothing
        Dim p_oDataTable As New DataTable
        Dim p_oDataColumn As DataColumn = Nothing
        Dim p_oSingleValue As Object = Nothing
        Dim p_bRecordFound As Boolean = False
        Dim p_iRecordsAffected As Integer = 0

        Try

            '//Executes Custom SQL using the Wisys Connection/SQL Transaction
            Using p_oSQLCommand As New SqlCommand
                p_oSQLCommand.CommandText = txtCustomSQL.Text
                If (rbReturnSingleValue.Checked) Then
                    '//ExecuteScalar returns single value back as an object that can be cast
                    p_iWisysReturnValue = c_oWisysConnection.SqlProcessor.ReturnSingleValue(p_oSQLCommand, True, p_oSingleValue, sWisysReturnMessage)

                    p_oDataColumn = p_oDataTable.Columns.Add()
                    p_oDataRow = p_oDataTable.NewRow()
                    p_oDataRow(0) = p_oSingleValue.ToString()
                    p_oDataTable.Rows.Add(p_oDataRow)

                ElseIf (rbReturnSingleRow.Checked) Then
                    '//Returns first datarow of the Select statement
                    p_iWisysReturnValue = c_oWisysConnection.SqlProcessor.ReturnSingleRow(p_oSQLCommand, True, p_oDataRow, p_bRecordFound, sWisysReturnMessage)

                    p_oDataTable = p_oDataRow.Table.Clone()
                    p_oDataTable.ImportRow(p_oDataRow)

                ElseIf (rbReturnDatatable.Checked) Then
                    '//Returns Datatable of the Select statement
                    p_iWisysReturnValue = c_oWisysConnection.SqlProcessor.ReturnValues(p_oSQLCommand, True, p_oDataTable, p_bRecordFound, sWisysReturnMessage)

                ElseIf (rbProcessSQL.Checked) Then
                    '//Executes SQL (Insert, Update, Delete, etc...) and returns the rows affected
                    p_iWisysReturnValue = c_oWisysConnection.SqlProcessor.ProcessSQL(p_oSQLCommand, True, p_iRecordsAffected, sWisysReturnMessage)

                    p_oDataColumn = p_oDataTable.Columns.Add()
                    p_oDataColumn.ColumnName = "Records Affected"
                    p_oDataRow = p_oDataTable.NewRow()
                    p_oDataRow(0) = p_iRecordsAffected.ToString()
                    p_oDataTable.Rows.Add(p_oDataRow)

                End If
            End Using

            c_oBindingSource.DataSource = p_oDataTable

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue
    End Function
#End Region

#Region "Events"

    Private Sub btnExecute_Click(sender As System.Object, e As System.EventArgs) Handles btnExecute.Click

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try
            '//Start Wisys SQL Transaction
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//Execute Custom SQL
            p_iWisysReturnValue = ExecuteSQL(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Execute SQL")
            End If

            '//Close Wisys Connection
            Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
            p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Execute SQL")

        End Try
    End Sub

    Private Sub txtCustomSQL_Leave(sender As System.Object, e As System.EventArgs) Handles txtCustomSQL.Leave
        If (txtCustomSQL.Text.Trim = "") Then
            DefaultCustomSQL()
        End If
    End Sub

    Private Sub txtCustomSQL_Enter(sender As System.Object, e As System.EventArgs) Handles txtCustomSQL.Enter
        If (txtCustomSQL.Text = c_CUSTOMSQLDEFAULT) Then
            txtCustomSQL.Text = ""
            txtCustomSQL.ForeColor = DefaultForeColor
        End If
    End Sub

#End Region



End Class
