﻿Imports Wisys.AllSystem
Imports Wisys.Im

Public Class ucWBWisysConnection

#Region "Variables"

    Dim c_oWisysConnection As Wisys.AllSystem.ConnectionInfo
    Dim c_oInventoryTables As Wisys.Im.InventoryTables

#End Region

#Region "Properties"

#End Region

#Region "Constructor"

    Public Sub New(oWisysConnection As Wisys.AllSystem.ConnectionInfo)

        ' This call is required by the designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.
        '//*We'll ignore oWisysConnection in this exmaple....
        c_oInventoryTables = New Wisys.Im.InventoryTables
    

    End Sub

#End Region

#Region "Public Methods"

#End Region

#Region "Private Methods"

    Private Function ExecuteSQLTransaction(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = ReturnCodes.SUCCESSFUL
        Dim p_bRecordFound As Boolean = False
        Dim p_iRecordsUpdated As Integer = 0
        Try
            '//*Best Practice - Call the class's Connection method before any other actions (i.e. set/get properties, calling methods, etc...)
            c_oInventoryTables.Connection(c_oWisysConnection)

            '//Read Item Master
            p_iWisysReturnValue = c_oInventoryTables.Imitmidx.Read(txtItemNo.Text, True, p_bRecordFound, sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If
            If (p_bRecordFound = False) Then
                sWisysReturnMessage = Wisys.AllSystem.Constants.ITEM_NO_NOT_FOUND
                Return ReturnCodes.FAILED
            End If

            '//Update Item Master
            c_oInventoryTables.Imitmidx.User_def_fld_5 = txtUserDefinedField5.Text
            c_oInventoryTables.Imitmidx.User = txtUserName.Text
            p_iWisysReturnValue = c_oInventoryTables.Imitmidx.Update(True, p_iRecordsUpdated, sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Function ExecuteQuery(ByRef sWisysReturnMessage As String) As Integer

        Dim p_iWisysReturnValue As Integer = ReturnCodes.SUCCESSFUL
        Dim p_bRecordFound As Boolean = False

        Try
            '//*Best Practice - Call the class's Connection method before any other actions (i.e. set/get properties, calling methods, etc...)
            c_oInventoryTables.Connection(c_oWisysConnection)

            p_iWisysReturnValue = c_oInventoryTables.Imitmidx.Read(txtItemNo.Text, False, p_bRecordFound, sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                Return p_iWisysReturnValue
            End If
            If (p_bRecordFound = False) Then
                sWisysReturnMessage = Wisys.AllSystem.Constants.ITEM_NO_NOT_FOUND
                Return ReturnCodes.FAILED
            End If

            DisplayItem()

        Catch ex As Exception
            sWisysReturnMessage = ex.Message
            p_iWisysReturnValue = ReturnCodes.FAILED

        End Try

        Return p_iWisysReturnValue

    End Function

    Private Sub DisplayItem()

        txtItemNo.Text = c_oInventoryTables.Imitmidx.Item_no
        txtUserDefinedField5.Text = c_oInventoryTables.Imitmidx.User_def_fld_5

    End Sub

#End Region

#Region "Events"

    Private Sub btnSetConnection_Click(sender As System.Object, e As System.EventArgs) Handles btnSetConnection.Click


        '//*********************************************
        '//For better performance, the ConnectionInfo class should typically be instantiated one time at an upper level of the application/class
        '//in conjunction with calling ConnectionInfo.Parameters method that sets the SQL Server and Database.
        '//The ConnectionInfo object can then be passed across the application and you can simply call the OpenWisysConnection/CloseWisysConnection methods
        '//as needed.
        '//*********************************************
        c_oWisysConnection = New Wisys.AllSystem.ConnectionInfo()


        '//The Wisys Connection uses a predefined SQL Server User "WiSysUser" that is created via the Wisys Product Updater
        '//Use the following Parameter method overload to assign the SQL Server, Database, and optionally the Application Name
        '//The application name will be set to a Macola's default value "macmss" if the application name is not passed
        c_oWisysConnection.Parameters(txtSQLServer.Text, txtDatabase.Text, "macmss")

    End Sub

    Private Sub btnExecuteQuery_Click(sender As System.Object, e As System.EventArgs) Handles btnExecuteQuery.Click

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try
            '//Open Wisys Connection (Query Mode)
            '//Set SQLTransactionWrapper parameter to False
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(False, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//Convert Quote to Order
            p_iWisysReturnValue = ExecuteQuery(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Execute Query")
            End If

            '//Close Wisys Connection
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(TrxEnums.TransactionAction.NoTransaction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Execute Query")

        End Try

    End Sub

    Private Sub btnExecuteSQLTransaction_Click(sender As System.Object, e As System.EventArgs) Handles btnExecuteSQLTransaction.Click

        Dim p_iWisysReturnValue As Integer = 0
        Dim p_sWisysReturnMessage As String = ""

        Try
            '//Start Wisys SQL Transaction
            '//Set SQLTransactionWrapper parameter to True
            p_iWisysReturnValue = c_oWisysConnection.OpenWisysConnection(True, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Open Connection")
                Return
            End If

            '//Execute SQL Transaction
            p_iWisysReturnValue = ExecuteSQLTransaction(p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Execute SQL Transaction")
            End If

            '//Close Wisys Connection
            '//When using the ConnectionInfo class in a SQL Transaction Wrapper it's important that the CloseWisysConnection 
            '//is called to ensure that SQL Server does not maintain record locks and 
            '//that any MacLock records created by the transaction are cleared
            Dim p_eTransactionAction As Wisys.AllSystem.TrxEnums.TransactionAction
            p_eTransactionAction = If(p_iWisysReturnValue = SUCCESSFUL, Wisys.AllSystem.TrxEnums.TransactionAction.Commit, Wisys.AllSystem.TrxEnums.TransactionAction.Rollback)
            p_iWisysReturnValue = c_oWisysConnection.CloseWisysConnection(p_eTransactionAction, p_sWisysReturnMessage)
            If (p_iWisysReturnValue <> ReturnCodes.SUCCESSFUL) Then
                MessageBox.Show(p_sWisysReturnMessage, "Close Connection")
            End If

        Catch ex As Exception
            MessageBox.Show(ex.Message, "Execute SQL Transaction")

        End Try


    End Sub

#End Region




End Class
